Query Generator
===========

.. _query_generator:

Introduction
------------
The query generator module contains functions that can be used to generate a set of queries that follow the heuristics proposed by Rainer and Williams in `IST'18`_

.. _IST'18: https://www.sciencedirect.com/science/article/abs/pii/S0950584918302192

Usage
-----

To use the query_generator module:

.. code-block:: console

    >>> import coast_search
    >>> coast_search.query_generator.function(to_use)

or:
.. code-block:: console

    >>> from coast_search import query_generator
    >>> query_generator.function(to_use)

Functions
---------

.. automodule:: coast_search.query_generator
    :members:
    :undoc-members:
    :show-inheritance:
